PasswordResetResponse class

Annotations
  • @freezed

Constructors

PasswordResetResponse({String? email, @Default.new(OobCodeRequestType.PASSWORD_RESET) OobCodeRequestType requestType})
Default constructor
const
factory
PasswordResetResponse.fromJson(Map<String, dynamic> json)
JSON constructor
factory

Properties

copyWith → $PasswordResetResponseCopyWith<PasswordResetResponse>
no setterinherited
email → String?
User's email address.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
requestType → OobCodeRequestType
Type of the email action code. Should be "PASSWORD_RESET".
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited