RefreshResponse class

Annotations
  • @freezed

Constructors

RefreshResponse({required String expires_in, required String token_type, required String refresh_token, required String id_token, required String user_id, required String project_id})
Default constructor
const
factory
RefreshResponse.fromJson(Map<String, dynamic> json)
JSON constructor
factory

Properties

copyWith → $RefreshResponseCopyWith<RefreshResponse>
no setterinherited
expires_in → String
The number of seconds in which the ID token expires.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id_token → String
A Firebase Auth ID token.
no setterinherited
project_id → String
Your Firebase project ID.
no setterinherited
refresh_token → String
The Firebase Auth refresh token provided in the request or a new refresh token.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token_type → String
no setterinherited
user_id → String
The uid corresponding to the provided ID token.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited