RestApi class

A client wrapper class for the firebase authentication REST-Api.

The class methods itself are not extensively documented, instead all members link to their endpoint documentation of the Firebase API itself.

See https://firebase.google.com/docs/reference/rest/auth for more details.

Constructors

RestApi(Client client, String apiKey)
Create a new api instance
const

Properties

apiKey → String
The Firebase Web-API-Key to authenticate to the remote api
final
client → Client
The HTTP-Client used to access the remote api
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirmEmail(ConfirmEmailRequest request) → Future<ConfirmEmailResponse>
https://firebase.google.com/docs/reference/rest/auth#section-confirm-email-verification
delete(DeleteRequest request) → Future<void>
https://firebase.google.com/docs/reference/rest/auth#section-delete-account
fetchProviders(FetchProviderRequest request) → Future<FetchProviderResponse>
https://firebase.google.com/docs/reference/rest/auth#section-fetch-providers-for-email
getUserData(UserDataRequest request) → Future<UserDataResponse>
https://firebase.google.com/docs/reference/rest/auth#section-get-account-info
linkEmail(LinkEmailRequest request) → Future<LinkEmailResponse>
https://firebase.google.com/docs/reference/rest/auth#section-link-with-email-password
linkIdp(LinkIdpRequest request) → Future<LinkIdpResponse>
https://firebase.google.com/docs/reference/rest/auth#section-link-with-oauth-credential
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetPassword(PasswordResetRequest request) → Future<PasswordResetResponse>
Meta-Method for multiple API-Methods
sendOobCode(OobCodeRequest request, [String? locale]) → Future<OobCodeResponse>
Meta-Method for multiple API-Methods
signInWithCustomToken(CustomTokenSignInRequest request) → Future<CustomTokenSignInResponse>
https://firebase.google.com/docs/reference/rest/auth#section-verify-custom-token
signInWithIdp(IdpSignInRequest request) → Future<IdpSignInResponse>
https://firebase.google.com/docs/reference/rest/auth#section-sign-in-with-oauth-credential
signInWithPassword(PasswordSignInRequest request) → Future<PasswordSignInResponse>
https://firebase.google.com/docs/reference/rest/auth#section-sign-in-email-password
signUpAnonymous(AnonymousSignInRequest request) → Future<AnonymousSignInResponse>
https://firebase.google.com/docs/reference/rest/auth#section-sign-in-anonymously
signUpWithPassword(PasswordSignInRequest request) → Future<PasswordSignInResponse>
https://firebase.google.com/docs/reference/rest/auth#section-create-email-password
token({required String refresh_token, String grant_type = 'refresh_token'}) → Future<RefreshResponse>
https://firebase.google.com/docs/reference/rest/auth#section-refresh-token
toString() → String
A string representation of this object.
inherited
unlinkProvider(UnlinkRequest request) → Future<UnlinkResponse>
https://firebase.google.com/docs/reference/rest/auth#section-unlink-provider
updateEmail(EmailUpdateRequest request, [String? locale]) → Future<EmailUpdateResponse>
https://firebase.google.com/docs/reference/rest/auth#section-change-email
updatePassword(PasswordUpdateRequest request) → Future<PasswordUpdateResponse>
https://firebase.google.com/docs/reference/rest/auth#section-change-password
updateProfile(ProfileUpdateRequest request) → Future<ProfileUpdateResponse>
https://firebase.google.com/docs/reference/rest/auth#section-update-profile

Operators

operator ==(Object other) → bool
The equality operator.
inherited