UnlinkResponse class abstract

Implemented types

Constructors

UnlinkResponse({required String localId, String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, bool emailVerified})
const
factory
UnlinkResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → _$$UnlinkResponseCopyWith<_$UnlinkResponse>
no setter
displayName → String?
The display name for the account.
no setter
email → String?
The email of the account.
no setter
emailVerified → bool
Whether or not the account's email has been verified.
no setter
hashCode → int
The hash code for this object.
no setterinherited
localId → String
The uid of the current user.
no setter
passwordHash → String?
Hash version of the password.
no setter
photoUrl → Uri?
The photo Url for the account.
no setter
providerUserInfo → List<ProviderUserInfo>
List of all linked ProviderUserInfos.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult confirmEmail(ConfirmEmailResponse value), required TResult email(EmailUpdateResponse value), required TResult password(PasswordUpdateResponse value), required TResult profile(ProfileUpdateResponse value), required TResult linkEmail(LinkEmailResponse value), required TResult unlink(UnlinkResponse value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? confirmEmail(ConfirmEmailResponse value)?, TResult? email(EmailUpdateResponse value)?, TResult? password(PasswordUpdateResponse value)?, TResult? profile(ProfileUpdateResponse value)?, TResult? linkEmail(LinkEmailResponse value)?, TResult? unlink(UnlinkResponse value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult confirmEmail(ConfirmEmailResponse value)?, TResult email(EmailUpdateResponse value)?, TResult password(PasswordUpdateResponse value)?, TResult profile(ProfileUpdateResponse value)?, TResult linkEmail(LinkEmailResponse value)?, TResult unlink(UnlinkResponse value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult confirmEmail(String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, bool emailVerified)?, TResult email(String localId, String? email, String? passwordHash, List<ProviderUserInfo> providerUserInfo, String? idToken, String? refreshToken, String? expiresIn)?, TResult password(String localId, String? email, String? passwordHash, List<ProviderUserInfo> providerUserInfo, String? idToken, String? refreshToken, String? expiresIn)?, TResult profile(String localId, String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, String? idToken, String? refreshToken, String? expiresIn)?, TResult linkEmail(String localId, String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, bool emailVerified, String? idToken, String? refreshToken, String? expiresIn)?, TResult unlink(String localId, String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, bool emailVerified)?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult confirmEmail(String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, bool emailVerified), required TResult email(String localId, String? email, String? passwordHash, List<ProviderUserInfo> providerUserInfo, String? idToken, String? refreshToken, String? expiresIn), required TResult password(String localId, String? email, String? passwordHash, List<ProviderUserInfo> providerUserInfo, String? idToken, String? refreshToken, String? expiresIn), required TResult profile(String localId, String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, String? idToken, String? refreshToken, String? expiresIn), required TResult linkEmail(String localId, String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, bool emailVerified, String? idToken, String? refreshToken, String? expiresIn), required TResult unlink(String localId, String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, bool emailVerified)}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? confirmEmail(String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, bool emailVerified)?, TResult? email(String localId, String? email, String? passwordHash, List<ProviderUserInfo> providerUserInfo, String? idToken, String? refreshToken, String? expiresIn)?, TResult? password(String localId, String? email, String? passwordHash, List<ProviderUserInfo> providerUserInfo, String? idToken, String? refreshToken, String? expiresIn)?, TResult? profile(String localId, String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, String? idToken, String? refreshToken, String? expiresIn)?, TResult? linkEmail(String localId, String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, bool emailVerified, String? idToken, String? refreshToken, String? expiresIn)?, TResult? unlink(String localId, String? email, String? displayName, Uri? photoUrl, String? passwordHash, List<ProviderUserInfo> providerUserInfo, bool emailVerified)?}) → TResult?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited